@file:OptIn(kotlin.ExperimentalStdlibApi::class)
import kotlin.math.*

// sa^2/(x - dx) + dy
// (dx, dy) is center, x = dx, y = dy - asymptotes
data class Hyperbola(val dx: Double, val dy: Double, val sa: Double) {
    // f1(x) = a/x, f2(x) = b/x
    // f(x) = f1(x1) + f2(x2) : x1+x2=x, a/x1^2 = b/x2^2
    // x1 = sqrt(a)/(sqrt(a)+sqrt(b))x, x2 = sqrt(b)/(sqrt(a)+sqrt(b))x
    // f(x) = sqrt(a)(sqrt(a)+sqrt(b))/x + sqrt(b)(sqrt(a)+sqrt(b))/x = (sqrt(a)+sqrt(b))^2/x
    operator fun plus(other: Hyperbola) = Hyperbola(dx + other.dx, dy + other.dy, sa + other.sa)
    operator fun minus(other: Hyperbola) = Hyperbola(dx - other.dx, dy - other.dy, sa - other.sa)
    fun eval(x: Double) = sa * sa / (x - dx) + dy
    fun derivative(x: Double) = - sa * sa / (x - dx) / (x - dx)
    // - sa^2/(x-dx)^2 = d => -sa^2/d = (x-dx)^2 => x-dx = sa/sqrt(-d) => x = sa/sqrt(-d) + dx
    fun byDerivative(d: Double) = sa / sqrt(-d) + dx

    companion object {
        fun byPoint(sa: Double, x: Double, value: Double, derivative: Double) : Hyperbola {
            val derX = sa / sqrt(-derivative)
            val derY = sa * sa / derX
            return Hyperbola(x - derX, value - derY, sa)
        }
    }
}

data class HyperbolaPart(val hyp: Hyperbola, val fromX: Double, val toX: Double)

const val EPS = 1e-9

fun readOne() : List<HyperbolaPart> {
    val data = readInts()
    val n = data[0]
    val current = data.subList(1, n + 1)
    val required = run {
        val requiredInts = data.subList(n + 1, data.size)
        val total = requiredInts.sum()
        requiredInts.map { it.toDouble() / total }
    }
    val sum = current.sum()
    val changes = ((0 until n).map { current[it].toDouble() / required[it] - sum }.filter { it > 0 } + listOf(0.0)).sorted()
    return buildList {
        for ((l, r) in changes.zipWithNext()) {
            if (r - l < EPS) continue
            val mid = (l + r) / 2
            val a = (0 until n).sumOf { if (current[it] - required[it] * (sum + mid) > 0) -required[it] else required[it]  } - 1.0
            val b = (0 until n).sumOf { (if (current[it] - required[it] * (sum + mid) > 0) 1 else -1)  * (current[it] - required[it] * sum) }
            val c = sum.toDouble()
            require(b - a * c > EPS)
            // (ax + b)/(x + c) = a + (b - a c) / (x - (-c)
            val hyp = Hyperbola(-c, a, sqrt(b - a * c))
            add(HyperbolaPart(
                hyp,
                l, r
            ))
        }
    }
}

fun solveOne(hyps: List<HyperbolaPart>, position: Double) : Double {
    val pos = hyps.binarySearchBy(position) { it.toX }.let {
        if (it < 0) (-it - 1) else it
    }
    return if (pos == hyps.size) 
            0.0 
        else 
            hyps[pos].hyp
                .eval(position)
                .let { if (it < 1e-12) 0.0 else it } // for better answer on sample
}

fun main() {
    val (n, q) = readInts()
    val parts = List(n) { readOne() }
    val qs = readLongs()

    data class Event(val d: Double, val isAdd: Boolean, val sa: Double)
    val events = parts.flatten().flatMap {
        listOf(
            Event(it.hyp.derivative(it.fromX), true, it.hyp.sa),
            Event(it.hyp.derivative(it.toX), false, it.hyp.sa),
        )
    }.sortedBy { it.d }
    var currentSa = 0.0
    var currentPos = 0.0
    var currentValue = parts.sumOf { it[0].hyp.eval(0.0) }
    var currentD = Double.NEGATIVE_INFINITY
    var cnt = 0
    val result = buildList {
        for (event in events) {
            if (cnt > 0) {
                val fromX = currentPos
                val next = Hyperbola.byPoint(currentSa, currentPos, currentValue, currentD)
                val toX = next.byDerivative(event.d)
                if (abs(fromX - toX) > EPS) {
                    add(HyperbolaPart(next, fromX, toX))
                }
                currentValue = next.eval(toX)
                currentPos = toX
            }
            if (event.isAdd) {
                cnt += 1
                currentSa += event.sa
            } else {
                cnt -= 1
                currentSa -= event.sa
            }
            currentD = event.d
        }
    }
    println(qs.map { solveOne(result, it.toDouble()) }.joinToString("\n"))
}

private fun readLn() = readLine()!!
private fun readInt() = readLn().toInt()
private fun readLongs() = readStrings().map { it.toLong() }
private fun readStrings() = readLn().split(" ")
private fun readInts() = readStrings().map { it.toInt() }