#pragma once

#include <algorithm>
#include <array>
#include <cassert>
#include <istream>
#include <ostream>
#include <vector>
#include <optional>

#include "testlib.h"


namespace constraints {

constexpr int ONE_KKK = 1'000'000'000;

constexpr int MIN_X = -ONE_KKK;
constexpr int MAX_X = ONE_KKK;
constexpr int MIN_Y = -ONE_KKK;
constexpr int MAX_Y = ONE_KKK;

constexpr size_t MIN_SEGMENTS_N = 0;
constexpr size_t MAX_SEGMENTS_N = 100;

const std::map<std::string, std::pair<int, int>> by_coord = {
        {"x", {MIN_X, MAX_X}},
        {"y", {MIN_Y, MAX_Y}},
};

} // namespace constraints


namespace ctd {

constexpr size_t POINTS_N = 3;

struct point {
  int x{};
  int y{};

  point() = default;
  point(int x, int y) : x(x), y(y) {}

  void transpose() {
    std::swap(x, y);
  }

  friend bool operator==(const point &a, const point &b) {
    return a.x == b.x && a.y == b.y;
  }

  friend bool operator<(const point &a, const point &b) {
    return a.x < b.x || (a.x == b.x && a.y < b.y);
  }

  static point read(std::istream &stream) {
    int x, y;
    stream >> x >> y;
    return {x, y};
  }

  static point read(InStream &input, bool strict, const std::string &name) {
    int x = input.readInt(constraints::MIN_X, constraints::MAX_X, name + ".x");
    if (strict) {
      input.readSpace();
    }
    int y = input.readInt(constraints::MIN_Y, constraints::MAX_Y, name + ".y");
    if (strict) {
      input.readEoln();
    }
    return {x, y};
  }

  [[nodiscard]] int &get_coord(const std::string &axis) {
    ensuref(coord_map.count(axis), R"(`axis` should be "x" or "y")");
    return this->*coord_map.at(axis);
  }

  [[nodiscard]] int get_coord(const std::string &axis) const {
    ensuref(coord_map.count(axis), R"(`axis` should be "x" or "y")");
    return this->*coord_map.at(axis);
  }

private:
  static const std::map<std::string, int point::*> coord_map;
};

const std::map<std::string, int point::*> point::coord_map = {
        {"x", &ctd::point::x},
        {"y", &ctd::point::y},
};

struct test {
  std::array<point, POINTS_N> points{};

  void print(std::ostream &stream) const {
    for (auto p : points) {
      stream << p.x << ' ' << p.y << '\n';
    }
  }

  static test read(std::istream &stream) {
    test res;
    for (auto &i : res.points) {
      i = point::read(stream);
    }
    return res;
  }

  static test read(InStream &input) {
    test res;
    for (size_t i = 0; i < res.points.size(); i++) {
      res.points[i] = point::read(input, false, format("point_%zu", i));
    }
    return res;
  }
};

struct segment {
  point from{};
  point to{};

  [[nodiscard]] bool horizontal() const {
    return from.y == to.y;
  }

  [[nodiscard]] bool vertical() const {
    return from.x == to.x;
  }

  friend bool operator==(const segment &a, const segment &b) {
    return a.from == b.from && a.to == b.to;
  }

  static std::optional<segment> read(InStream &input, const std::string &name) {
    auto from = point::read(input, false, name + ".from");
    auto to = point::read(input, false, name + ".to");
    if (from == to) {
      return std::nullopt;
    }
    if (to < from) {
      std::swap(from, to);
    }
    segment seg{from, to};
    input.ensuref(
      seg.horizontal() || seg.vertical(),
      "Incorrect segment: from = (%d; %d), to = (%d; %d), segment is not vertical nor horizontal",
      from.x, from.y, to.x, to.y);
    return {{from, to}};
  }

  [[nodiscard]] int length() const {
    if (vertical()) {
      return std::abs(from.y - to.y);
    } else {
      assert(horizontal());
      return std::abs(from.x - to.x);
    }
  }

  [[nodiscard]] bool contains(const point &p) const {
    if (vertical()) {
      return p.x == from.x && from.y <= p.y && p.y <= to.y;
    } else {
      assert(horizontal());
      return p.y == from.y && from.x <= p.x && p.x <= to.x;
    }
  }

  void transpose() {
    from.transpose();
    to.transpose();
    if (to < from) {
      std::swap(from, to);
    }
  }

  static bool intersect(segment a, segment b) {
    if (a.vertical()) {
      a.transpose();
      b.transpose();
    }
    assert(a.horizontal());
    if (b.horizontal()) {
      return a.from.y == b.from.y && a.from.x <= b.to.x && b.from.x <= a.to.x;
    } else {
      assert(b.vertical());
      return a.from.x <= b.from.x && b.from.x <= a.to.x
          && b.from.y <= a.from.y && a.from.y <= b.to.y;
    }
  }
};

struct answer {
  std::vector<segment> segments;

  static answer read(InStream &input) {
    const size_t n = input.readInt(
      constraints::MIN_SEGMENTS_N,
      constraints::MAX_SEGMENTS_N,
      "segments_n");
    answer res;
    for (size_t i = 0; i < n; i++) {
      auto seg = segment::read(input, format("segment_%zu", i));
      if (seg.has_value()) {
        res.segments.push_back(*seg);
      }
    }
    return res;
  }
};

} // namespace ctd
