#include <algorithm>
#include <cassert>
#include <functional>
#include <iostream>
#include <map>
#include <numeric>
#include <random>
#include <set>
#include <vector>

struct point {
  int x{};
  int y{};

  friend bool operator==(const point &a, const point &b) {
    return a.x == b.x && a.y == b.y;
  }

  friend bool operator<(const point &a, const point &b) {
    return a.x < b.x && (a.x == b.x && a.y < b.y);
  }

  static point read() {
    int x, y;
    std::cin >> x >> y;
    return {x, y};
  }
};

std::ostream &operator<<(std::ostream &stream, const point &p) {
  return stream << p.x << ' ' << p.y;
}

struct dsu {
  dsu(size_t n)
    : parent_of(n)
    , size_of(n, 1) {
    std::iota(parent_of.begin(), parent_of.end(), 0);
  }

  size_t color(size_t node) const {
    while (node != parent_of[node]) {
      node = parent_of[node];
    }
    return node;
  }

  void unite(size_t a, size_t b) {
    a = color(a);
    b = color(b);
    if (size_of[a] < size_of[b]) {
      std::swap(a, b);
    }
    // a is larger than b
    set(parent_of[b], a);
    set(size_of[a], size_of[a] + size_of[b]);
  }

  size_t timestamp() const {
    return changes.size();
  }

  void rollback(size_t target_timestamp) {
    while (changes.size() > target_timestamp) {
      *changes.back().first = changes.back().second;
      changes.pop_back();
    }
  }

private:
  mutable std::vector<size_t> parent_of;
  std::vector<size_t> size_of;
  mutable std::vector<std::pair<size_t *, size_t>> changes;

  void set(size_t &var, size_t value) {
    changes.emplace_back(&var, var);
    var = value;
  }
};

using cost_t = long long;

struct edge {
  size_t from;
  size_t to;
  cost_t cost;
};

using edges_list_t = std::vector<edge>;

edges_list_t solve(
        const size_t n,
        const std::vector<size_t> &targets,
        const edges_list_t &edges) {

  edges_list_t best_solution = {};
  auto best_solution_cost = std::numeric_limits<cost_t>::max();

  dsu graph{n};
  edges_list_t taken_edges{};
  cost_t taken_edges_cost = 0;

  const std::function<void(size_t)> go = [&](size_t next_edge_idx) {
    bool targets_connected = true;
    for (auto target : targets) {
      targets_connected &= (graph.color(target) == graph.color(targets[0]));
    }
    if (targets_connected) {
      if (taken_edges_cost < best_solution_cost) {
        best_solution = taken_edges;
        best_solution_cost = taken_edges_cost;
      }
      return;
    }

    if (next_edge_idx >= edges.size()) {
      return;
    }

    const auto next_edge = edges[next_edge_idx];
    const auto state_ts = graph.timestamp();

    graph.unite(next_edge.from, next_edge.to);
    taken_edges.push_back(next_edge);
    taken_edges_cost += next_edge.cost;
    go(next_edge_idx + 1);

    graph.rollback(state_ts);
    taken_edges.pop_back();
    taken_edges_cost -= next_edge.cost;

    go(next_edge_idx + 1);
  };

  go(0);
  assert(!best_solution.empty());
  return best_solution;
}

int main() {
  const std::vector<point> target_pts = {
          point::read(),
          point::read(),
          point::read(),
  };

  std::set<int> xs, ys;
  for (auto pt : target_pts) {
    xs.insert(pt.x);
    ys.insert(pt.y);
  }

  std::vector<point> grid;
  for (int x : xs) {
    for (int y : ys) {
      grid.push_back({x, y});
    }
  }
  const auto index_of = [&](point pt) -> size_t {
    auto it = std::find(grid.begin(), grid.end(), pt);
    assert(it != grid.end());
    return it - grid.begin();
  };

  std::vector<size_t> targets;
  for (auto pt : target_pts) {
    targets.push_back(index_of(pt));
  }

  edges_list_t edges;
  {
    const auto add_edge = [&](point a, point b) {
      assert(a.x == b.x || a.y == b.y);
      cost_t length = std::abs(a.x - b.x) + std::abs(a.y - b.y);
      edges.push_back({index_of(a), index_of(b), length});
    };
    for (int x : xs) {
      for (auto y = ys.begin(); std::next(y) != ys.end(); y++) {
        add_edge({x, *y}, {x, *std::next(y)});
      }
    }
    for (auto x = xs.begin(); std::next(x) != xs.end(); x++) {
      for (int y : ys) {
        add_edge({*x, y}, {*std::next(x), y});
      }
    }
  }

  std::mt19937 random_gen{};
  std::shuffle(edges.begin(), edges.end(), random_gen);
  edges_list_t best_edges = solve(grid.size(), targets, edges);

  std::cout << best_edges.size() << '\n';
  for (auto edge : best_edges) {
    auto from = grid[edge.from];
    auto to = grid[edge.to];
    std::cout << from << ' ' << to << '\n';
  }
}
