pub mod solution {
//{"name":"heroes","group":"Manual","url":"","interactive":false,"timeLimit":2000,"tests":[{"input":"","output":""}],"testType":"multiNumber","input":{"type":"stdin","fileName":null,"pattern":null},"output":{"type":"stdout","fileName":null,"pattern":null},"languages":{"java":{"taskClass":"heroes"}}}

use std::cmp::max;
use std::cmp::min;
use std::cmp::Ordering;

use crate::algo_lib::collections::array_2d::Array2D;
use crate::algo_lib::collections::last_exn::LastExn;
use crate::algo_lib::geometry::point::PointT;
use crate::algo_lib::io::output::output;
use crate::algo_lib::io::task_io_settings::TaskIoType;
use crate::algo_lib::io::task_runner::run_task;
use crate::algo_lib::io::input::Input;
use crate::algo_lib::io::task_io_settings::TaskIoSettings;
use crate::algo_lib::math::gcd::lcm;
use crate::algo_lib::misc::binary_search::binary_search_first_true;
use crate::algo_lib::misc::min_max::UpdateMinMax;
use crate::algo_lib::misc::pref_sum::PrefSum;
use crate::algo_lib::misc::rand::Random;
use crate::algo_lib::misc::rec_function::Callable6;
use crate::algo_lib::misc::rec_function::RecursiveFunction6;
#[allow(unused)]
use crate::dbg;
use crate::out;
use crate::out_line;

fn solve(input: &mut Input, _test_case: usize) {
    let n = input.usize();
    let damage = input.i64();
    let health = input.i64();
    let a = input.vec::<i64>(n);
    let res = solve_fast(&a, damage, health);
    out_line!(res);
}

///
/// Works in O(a.len * log^3(damage * health))
///
/// There are O(log) segments for each a_i (hopefully).
/// To find each segment we do a binary search over "angle".
/// Inside each binary serach we calculate number of lattice points inside
/// a triangle, which also works in O(log).
///
fn solve_fast(a: &[i64], damage: i64, health: i64) -> i64 {
    let mut segments = vec![];
    for &cnt in a.iter() {
        segments.append(&mut gen_segments_fast(cnt, health, damage));
    }
    segments.sort();
    let mut combined_seg = Segment::EMPTY;
    for seg in segments.iter() {
        combined_seg = combined_seg.join(seg);
    }
    let start_alive = a.iter().sum::<i64>();
    1 + start_alive * combined_seg.turns - combined_seg.pref_sum
}

fn gen_segments_fast(cnt: i64, health: i64, damage: i64) -> Vec<Segment> {
    let mut segs = vec![];
    let mut from_x = 0;
    let mut a = damage;
    let mut b = health;
    let need_hits = (health * cnt + damage - 1) / damage;
    // f(x) = a/b * x;
    while from_x + 1 < need_hits {
        let p = find_lattice_point_in_triangle(need_hits - 1 - from_x, a, b);

        assert!(p.x > 0);

        let next_x = from_x + p.x;

        let pref_sum = {
            let offset = (from_x * damage) % health + damage;
            div_sum(p.x, offset, damage, health)
        };

        segs.push(Segment {
            total_killed: (next_x * damage) / health - (from_x * damage) / health,
            turns: p.x,
            pref_sum,
        });
        from_x += p.x;
        a = (from_x * damage) / health;
        b = from_x;
    }
    {
        let done = ((need_hits - 1) * damage) / health;
        assert!(done < cnt);
        let left = min(cnt, (need_hits * damage) / health) - done;
        segs.push(Segment {
            total_killed: left,
            turns: 1,
            pref_sum: left,
        });
    }
    while segs.len() >= 2 {
        let n = segs.len();
        if segs[n - 2].cmp(&segs[n - 1]) != Ordering::Less {
            let p1 = segs.pop().unwrap();
            let p2 = segs.pop().unwrap();
            segs.push(p2.join(&p1));
        } else {
            break;
        }
    }
    for w in segs.windows(2) {
        assert!(w[0].cmp(&w[1]) == Ordering::Less);
    }
    assert!(segs.len() < 40);

    segs
}

#[derive(Clone, Copy, Debug)]
struct Segment {
    total_killed: i64,
    turns: i64,
    pref_sum: i64,
}

impl Segment {
    pub fn join(&self, other: &Self) -> Self {
        Self {
            total_killed: self.total_killed + other.total_killed,
            turns: self.turns + other.turns,
            pref_sum: self.pref_sum + other.pref_sum + self.total_killed * other.turns,
        }
    }

    const EMPTY: Self = Self {
        total_killed: 0,
        turns: 0,
        pref_sum: 0,
    };
}

impl PartialEq for Segment {
    fn eq(&self, other: &Self) -> bool {
        self.total_killed == other.total_killed
            && self.turns == other.turns
            && self.pref_sum == other.pref_sum
    }
}

impl PartialOrd for Segment {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some((other.total_killed * self.turns).cmp(&(self.total_killed * other.turns)))
    }
}

impl Eq for Segment {}

impl Ord for Segment {
    fn cmp(&self, other: &Self) -> Ordering {
        self.partial_cmp(&other).unwrap()
    }
}

type Point = PointT<i64>;

///
/// Let's look at all lattice points (x, y) such that:
/// - x > 0
/// - x <= max_x
/// - y <= (a/b) * x
/// - (y/x) -> maximum possible. Over all such points, maximize x.
///
///
fn find_lattice_point_in_triangle(max_x: i64, a: i64, b: i64) -> Point {
    const MAX: i64 = 1.2e9 as i64;
    assert!(max_x < MAX);
    assert!(max_x > 0);
    assert!(a * max_x / b < MAX);
    assert!(a < MAX);
    assert!(b < MAX);
    assert!(b > 0);

    let denum = (max_x * max_x / b + 1) * b;
    assert!(denum >= max_x * max_x);
    assert_eq!(denum % b, 0);

    let max_num = (denum / b) * a;
    assert!(max_num <= MAX * MAX);
    let total_points = num_points_in_triangle(max_x, a, b);
    let total_points_via_denum = num_points_in_triangle(max_x, max_num, denum);
    assert_eq!(total_points, total_points_via_denum);
    let biggest_num = binary_search_first_true(0..max_num + 1, |num| {
        num_points_in_triangle(max_x, num, denum) == total_points
    });
    if biggest_num == 0 {
        return Point { x: max_x, y: 0 };
    }
    let on_line = total_points - num_points_in_triangle(max_x, biggest_num - 1, denum);
    let x = binary_search_first_true(0..max_x + 1, |cur_max_x| {
        num_points_in_triangle(cur_max_x, biggest_num, denum)
            - num_points_in_triangle(cur_max_x, biggest_num - 1, denum)
            == on_line
    });
    Point { x, y: (x * a) / b }
}

///
/// Number of lattice points (x, y)
///
/// 0 <= x <= max_x
/// 0 <= y <= (a/b) * x
///
///
fn num_points_in_triangle(max_x: i64, a: i64, b: i64) -> i64 {
    const MAX: i64 = 1.2e9 as i64;
    assert!(max_x < MAX);
    assert!(a < MAX * MAX);
    assert!(b < MAX * MAX);
    assert!((a as i128) < (MAX * MAX / (max_x + 1)) as i128 * (b as i128));

    div_sum(max_x + 1, 0, a, b)
}

///
/// Copied from: https://github.com/bicsi/kactl/blob/master/content/number-theory/ModSum.h
///
/// Calculates $\sum{i=0}^{to - 1}{(ki+c) / m}$
///
/// TODO: think about i128 here...
fn div_sum(to: i64, c: i64, k: i64, m: i64) -> i64 {
    let to = to as i128;
    let mut c = c as i128;
    let mut k = k as i128;
    let m = m as i128;

    const MAX: i128 = 1.2e9 as i128;
    const MAX2: i128 = MAX * MAX;
    assert!(to < MAX);
    assert!(k / m <= MAX2 / (to + 1) / (to + 1));
    assert!(c / m <= MAX2 / (to + 1));

    fn sum_sq(to: i64) -> i64 {
        to / 2 * ((to - 1) | 1)
    }

    let mut res = k / m * sum_sq(to as i64) as i128 + c / m * to;
    k %= m;
    c %= m;
    if k != 0 {
        // TODO: this overflows (?) i64, so we use i128 :(
        let to2 = (to * k + c) / m;
        assert!(to < MAX2 / (to2 + 1));
        res += to * to2;
        res -= div_sum(to2 as i64, (m - 1 - c) as i64, m as i64, k as i64) as i128 + to2;
    }
    assert!(res < MAX2);
    assert!(res >= 0);
    return res as i64;
}

pub(crate) fn run(mut input: Input) -> bool {
    let t = input.read();
    for i in 0usize..t {
        solve(&mut input, i + 1);
    }
    output().flush();
    input.skip_whitespace();
    input.peek().is_none()
}

#[allow(unused)]
pub fn submit() -> bool {
    let io = TaskIoSettings {
        is_interactive: false,
        input: TaskIoType::Std,
        output: TaskIoType::Std,
    };

    run_task(io, run)
}

/*


End of the actual solution. Some slow solutions / stress is below.


*/

fn gen_killed(cnt: i64, damage: i64, health: i64) -> Vec<i64> {
    let mut res = vec![];
    let mut cur_health = cnt * health;
    while cur_health != 0 {
        let cur_cnt = (cur_health + health - 1) / health;
        let next_health = max(0, cur_health - damage);
        let next_cnt = (next_health + health - 1) / health;
        res.push(cur_cnt - next_cnt);
        cur_health = next_health;
    }
    res
}

fn combine_kills(a: &[i64], b: &[i64]) -> Vec<i64> {
    let n = a.len();
    let m = b.len();

    let a_pref = a.pref_sum();
    let b_pref = b.pref_sum();
    let start_alive = *a_pref.last_exn() + *b_pref.last_exn();

    // dp[i][j] - used `i` items from `a`, `j` items from `b`
    // (what is the smallest amount of damage recieved, prev i, prev j)

    #[derive(PartialEq, Eq, PartialOrd, Ord, Clone, Copy)]
    struct Value {
        damage_recieved: i64,
        prev_i: usize,
        prev_j: usize,
    }

    let mut dp = Array2D::new(
        Value {
            damage_recieved: i64::MAX,
            prev_i: 0,
            prev_j: 0,
        },
        n + 1,
        m + 1,
    );
    dp[0][0] = Value {
        damage_recieved: 0,
        prev_i: 0,
        prev_j: 0,
    };

    for i in 0..=n {
        for j in 0..=m {
            assert!(dp[i][j].damage_recieved != i64::MAX);
            let still_alive = start_alive - a_pref[i] - b_pref[j];
            let expected_damage = dp[i][j].damage_recieved + still_alive;
            if i < n {
                dp[i + 1][j].update_min(Value {
                    damage_recieved: expected_damage - a[i],
                    prev_i: i,
                    prev_j: j,
                });
            }
            if j < m {
                dp[i][j + 1].update_min(Value {
                    damage_recieved: expected_damage - b[j],
                    prev_i: i,
                    prev_j: j,
                });
            }
        }
    }
    let mut res = vec![];
    {
        let mut i = n;
        let mut j = m;
        while i != 0 || j != 0 {
            let val = dp[i][j];
            if val.prev_i != i {
                assert_eq!(val.prev_j, j);
                i = val.prev_i;
                res.push(a[i]);
            } else {
                assert!(val.prev_j != j);
                j = val.prev_j;
                res.push(b[j]);
            }
        }
        res.reverse();
    }
    res
}

#[allow(unused)]
fn solve_slow(a: &[i64], damage: i64, health: i64) -> i64 {
    let kills: Vec<_> = a
        .iter()
        .map(|&cnt| gen_killed(cnt, damage, health))
        .collect();

    let mut combined_kills = vec![];
    for another in kills.into_iter() {
        combined_kills = combine_kills(&combined_kills, &another);
    }

    let mut alive_cnt: i64 = a.iter().sum();
    let mut res = 0;
    for &k in combined_kills.iter() {
        alive_cnt -= k;
        res += alive_cnt
    }
    res + 1
}

fn calc_kills(order: &[&[i64]]) -> i64 {
    let mut cnt = 0;
    for o in order.iter() {
        cnt += o.iter().sum::<i64>();
    }
    let mut res = 0;
    for a in order.iter() {
        for &x in a.iter() {
            cnt -= x;
            res += cnt;
        }
    }
    res
}

fn combine_kills3_slow(a: &[i64], b: &[i64]) -> Vec<i64> {
    let mut best_ans = (i64::MAX, vec![]);

    let mut dfs = RecursiveFunction6::new(
        |f,
         a: &[i64],
         b: &[i64],
         cur_kills: i64,
         max_splits_a: usize,
         max_splits_b: usize,
         how: Vec<i64>| {
            if a.len() == 0 && b.len() == 0 {
                best_ans.update_min((cur_kills, how));
                return;
            }
            if max_splits_a == 0 && a.len() != 0 {
                return;
            }
            if max_splits_b == 0 && b.len() != 0 {
                return;
            }
            // if max_splits_a == 1 && a.len() > 1 {
            //     return;
            // }
            // if max_splits_b == 1 && b.len() > 1 {
            //     return;
            // }
            if a.len() != 0 && max_splits_a > 0 {
                for pos in 1..=a.len() {
                    let mut new_how = how.clone();
                    new_how.append(&mut a[0..pos].to_vec());
                    let mut new_kills = cur_kills;
                    let mut cur_alive = a.iter().sum::<i64>() + b.iter().sum::<i64>();
                    for x in a[0..pos].iter() {
                        cur_alive -= x;
                        new_kills += cur_alive;
                    }
                    f.call(
                        &a[pos..],
                        b,
                        new_kills,
                        max_splits_a - 1,
                        max_splits_b,
                        new_how,
                    );
                }
            }
            if b.len() != 0 && max_splits_b > 0 {
                for pos in 1..=b.len() {
                    let mut new_how = how.clone();
                    new_how.append(&mut b[0..pos].to_vec());
                    let mut new_kills = cur_kills;
                    let mut cur_alive = a.iter().sum::<i64>() + b.iter().sum::<i64>();
                    for x in b[0..pos].iter() {
                        cur_alive -= x;
                        new_kills += cur_alive;
                    }
                    f.call(
                        a,
                        &b[pos..],
                        new_kills,
                        max_splits_a,
                        max_splits_b - 1,
                        new_how,
                    );
                }
            }
        },
    );
    dfs.call(a, b, 0, 2, 2, vec![]);
    assert_ne!(best_ans.0, i64::MAX);
    best_ans.1
}

#[allow(unused)]
fn stress3() {
    const MAX: i64 = 600;

    for health in 1..MAX {
        dbg!(health);
        for damage in 1..MAX {
            let a = gen_killed(100, damage, health);
            let a = a[..a.len() - 1].to_vec();
            if a.len() == 0 {
                continue;
            }
            let min_val = *a.iter().min().unwrap();
            let mut exist_two_mins = false;
            let mut exist_two_maxs = false;
            for w in a.windows(2) {
                if w[0] == min_val && w[1] == min_val {
                    exist_two_mins = true;
                }
                if w[0] == min_val + 1 && w[1] == min_val + 1 {
                    exist_two_maxs = false;
                }
            }
            assert!(!exist_two_maxs || !exist_two_mins);
        }
    }
}

#[derive(Debug)]
struct Group {
    value: i64,
    cnt: usize,
}

fn split_groups(a: &[i64]) -> Vec<Group> {
    let mut res = vec![];
    let mut it = 0;
    while it != a.len() {
        let mut it2 = it;
        while it2 != a.len() && a[it2] == a[it] {
            it2 += 1;
        }
        res.push(Group {
            value: a[it],
            cnt: it2 - it,
        });
        it = it2;
    }
    res
}

fn sum_prefix(a: &[i64]) -> i64 {
    let pref_sum = a.pref_sum();
    pref_sum.iter().sum()
}

fn gen_segments(cnt: i64, health: i64, damage: i64) -> Vec<Segment> {
    let mut kills = &gen_killed(cnt, damage, health)[..];
    let mut segs = vec![];
    while kills.len() != 0 {
        let mut last = Segment {
            total_killed: kills[0],
            turns: 1,
            pref_sum: kills[0],
        };
        let mut best = last;
        for &val in &kills[1..] {
            let next = Segment {
                total_killed: last.total_killed + val,
                turns: last.turns + 1,
                pref_sum: last.pref_sum + val + last.total_killed,
            };
            last = next;
            if next.cmp(&best) != Ordering::Greater {
                best = next
            }
        }
        segs.push(best);
        kills = &kills[best.turns as usize..];
    }
    // dbg!(segs);
    assert!(segs.len() < 20);
    segs
}

fn segments_solve(cnt1: i64, cnt2: i64, health: i64, damage: i64) -> i64 {
    let mut segs = vec![];
    segs.append(&mut gen_segments(cnt1, health, damage));
    segs.append(&mut gen_segments(cnt2, health, damage));
    // dbg!(segs);
    segs.sort();
    let mut res = 0;
    let mut cnt_ones = 0;
    for s in segs.iter() {
        res += cnt_ones * s.turns;
        res += s.pref_sum;
        cnt_ones += s.total_killed;
    }
    res
}

#[allow(unused)]
fn stress331() {
    const MAX: i64 = 5000;
    for it in 1600.. {
        dbg!(it);
        let mut rnd = Random::new(it);
        let health = rnd.gen_in_range(1..MAX);
        let damage = rnd.gen_in_range(1000..MAX);
        let cnt1 = rnd.gen_in_range(1..MAX / 5);
        let cnt2 = rnd.gen_in_range(1..MAX / 5);
        dbg!(health, damage, cnt1, cnt2);
        let need1 = ((cnt1 * health + damage - 1) / damage) as usize;
        let need2 = ((cnt2 * health + damage - 1) / damage) as usize;
        // dp[where last hit?][segs1][segs2][hit1][hit2] -> sum prefix killed, try to maximize
        const MAX_SEGS: usize = 5;
        let mut dp =
            vec![vec![vec![vec![vec![i64::MIN; need2 + 1]; need1 + 1]; MAX_SEGS]; MAX_SEGS]; 2];
        dp[0][1][0][0][0] = 0;
        dp[1][0][1][0][0] = 0;
        for hit1 in 0..=need1 {
            for hit2 in 0..=need2 {
                for seg1 in 0..MAX_SEGS {
                    for seg2 in 0..MAX_SEGS {
                        for last in 0..2 {
                            let cur = dp[last][seg1][seg2][hit1][hit2];
                            if cur == i64::MIN {
                                continue;
                            }
                            for next in 0..2 {
                                if hit1 == need1 && next == 0 {
                                    continue;
                                }
                                if hit2 == need2 && next == 1 {
                                    continue;
                                }
                                let nhit1 = hit1 + (if next == 0 { 1 } else { 0 });
                                let nhit2 = hit2 + (if next == 1 { 1 } else { 0 });
                                let nseg1 = seg1 + (if last == 1 && next == 0 { 1 } else { 0 });
                                let nseg2 = seg2 + (if last == 0 && next == 1 { 1 } else { 0 });
                                if nseg1 >= MAX_SEGS || nseg2 >= MAX_SEGS {
                                    continue;
                                }
                                let killed1 = min(cnt1, (nhit1 as i64) * damage / health);
                                let killed2 = min(cnt2, (nhit2 as i64) * damage / health);

                                dp[next][nseg1][nseg2][nhit1][nhit2]
                                    .update_max(cur + killed1 + killed2);
                            }
                        }
                    }
                }
            }
        }
        // store [maximum prefix sums; -max(seg1, seg2)]
        let mut best_res = (0, 0);
        for cur in 0..2 {
            for seg1 in 0..MAX_SEGS {
                for seg2 in 0..MAX_SEGS {
                    let dp = dp[cur][seg1][seg2][need1][need2];
                    if dp == i64::MIN {
                        continue;
                    }
                    let max_segs = (max(seg1, seg2) as i32) * -1;
                    best_res.update_max((dp, max_segs));
                }
            }
        }
        let segs_used = best_res.1 * -1;
        if segs_used > 3 {
            dbg!(best_res);
        }
        assert!(segs_used <= 3);
        // dbg!(best_res);
        // let correct = {
        //     let a = gen_killed(cnt1, damage, health);
        //     let b = gen_killed(cnt2, damage, health);
        //     let optimal = combine_kills(&a, &b);
        //     sum_prefix(&optimal)
        // };
        // if correct != best_res {
        //     assert_eq!(correct, best_res);
        // }
    }
}

#[allow(unused)]
fn stress84846723() {
    let mut max_segs = 0;
    const MAX: i64 = 50000000;
    for it in 1600.. {
        let mut rnd = Random::new(it);
        let health = rnd.gen_in_range(1..MAX);
        let damage = rnd.gen_in_range(10000..MAX);
        let cnt = rnd.gen_in_range(1..MAX / 10);
        let need1 = ((cnt * health + damage - 1) / damage) as usize;

        if need1 > 10_000_000 {
            dbg!("skip");
            continue;
        }
        dbg!(it);
        dbg!(health, damage, cnt);

        let segs = gen_segments(cnt, health, damage);
        max_segs.update_max(segs.len());
        dbg!(segs.len(), max_segs);
    }
}

fn find_lattice_point_in_triangle_slow(max_x: i64, a: i64, b: i64) -> Point {
    let mut best = Point { x: 1, y: 0 };
    for x in 1..=max_x {
        let y = a * x / b;
        let p = Point { x, y };
        if Point::vect_mul2(&best, &p) >= 0 {
            best = p;
        }
    }
    best
}

#[allow(unused)]
fn stress42255() {
    for it in 21607.. {
        let mut rnd = Random::new(it);
        const MAX: i64 = 1_000_000_000;
        let max_x = rnd.gen_in_range(1..MAX);
        let a = rnd.gen_in_range(1..MAX);
        let b = rnd.gen_in_range(1..MAX);
        if a * max_x / b > 1_000_000_000 {
            continue;
        }
        dbg!(it);
        let my = find_lattice_point_in_triangle(max_x, a, b);
        let correct = find_lattice_point_in_triangle_slow(max_x, a, b);
        assert_eq!(my, correct);
    }
}

#[allow(unused)]
fn stress() {
    for it in 1.. {
        dbg!(it);
        let mut rnd = Random::new(it);
        const MAX: i64 = 1000000;
        let cnt = rnd.gen_in_range(1..MAX);
        let health = rnd.gen_in_range(1..MAX);
        let damage = rnd.gen_in_range(1..MAX);
        let correct_segs = gen_segments(cnt, health, damage);
        let my_segs = gen_segments_fast(cnt, health, damage);
        assert_eq!(my_segs, correct_segs);
    }
}

#[allow(unused)]
fn stress883() {
    const MAX: i64 = 50000;
    for it in 1600.. {
        let mut rnd = Random::new(it);
        let health = rnd.gen_in_range(1..MAX);
        let damage = rnd.gen_in_range(10000..MAX);
        let cnt1 = rnd.gen_in_range(1..MAX / 10);
        let cnt2 = rnd.gen_in_range(1..MAX / 10);
        let need1 = ((cnt1 * health + damage - 1) / damage) as usize;
        let need2 = ((cnt2 * health + damage - 1) / damage) as usize;

        if need1 * need2 > 1_000_000 {
            dbg!("skip");
            continue;
        }
        dbg!(it);
        dbg!(health, damage, cnt1, cnt2);

        // dbg!(best_res);
        let correct = {
            let a = gen_killed(cnt1, damage, health);
            let b = gen_killed(cnt2, damage, health);
            let optimal = combine_kills(&a, &b);
            sum_prefix(&optimal)
        };
        let my = segments_solve(cnt1, cnt2, health, damage);
        assert_eq!(correct, my);
        // if correct != best_res {
        //     assert_eq!(correct, best_res);
        // }
    }
}

#[allow(unused)]
fn stress33() {
    const MAX: i64 = 200;

    for health in 1..MAX {
        dbg!(health);
        for damage in 1..health {
            let cycle = lcm(health, damage);
            let cnt = cycle / health;
            if cnt == 1 {
                continue;
            }
            let a = gen_killed(cnt, damage, health);
            let groups = split_groups(&a);

            // dbg!(damage, cycle, cnt);
            // dbg!(groups);

            for i in (0..groups.len()).step_by(2) {
                assert_eq!(groups[i].value, groups[0].value);
            }
            for i in (1..groups.len()).step_by(2) {
                assert_eq!(groups[i].value, groups[1].value);
            }
            assert_eq!(groups[0].value + 1, groups[1].value);
            for start_pos in 1..a.len() {
                let mut sum_start = 0;
                let mut sum_suf = 0;
                let max_len = a.len() - start_pos;
                for i in 0..max_len {
                    sum_start += a[i];
                    sum_suf += a[i + start_pos];
                    assert!(sum_suf >= sum_start);
                }
            }
            let mut lens = vec![];
            let mut sum_len = 0;
            for i in 0..groups.len() / 2 {
                sum_len += groups[i * 2].cnt;
                sum_len += groups[i * 2 + 1].cnt;
                lens.push(sum_len);
            }
            for &l1 in lens.iter() {
                for &l2 in lens.iter() {
                    let first = &a[0..l1];
                    let second = &a[0..l2];
                    let best = combine_kills(first, second);
                    let best_ans = sum_prefix(&best);
                    let mut my = 0;
                    for (o1, o2) in [(first, second), (second, first)].iter() {
                        let mut joined = vec![];
                        joined.append(&mut o1.to_vec());
                        joined.append(&mut o2.to_vec());
                        let cur = sum_prefix(&joined);
                        my.update_max(cur);
                    }
                    if best_ans != my {
                        dbg!(first);
                        dbg!(second);
                        dbg!(damage);
                        dbg!(a);
                        assert_eq!(best_ans, my);
                    }
                }
            }
        }
    }
}

#[allow(unused)]
fn stress2() {
    for it in 1.. {
        dbg!(it);
        let mut rnd = Random::new(it + 7782228);
        const MAX_CNT: i64 = 20;
        const MAX_HEALTH: i64 = 20;
        let cnt1 = rnd.gen_in_range(1..MAX_CNT);
        let cnt2 = rnd.gen_in_range(1..MAX_CNT);
        let health = rnd.gen_in_range(2..MAX_HEALTH);
        let damage = rnd.gen_in_range(1..MAX_HEALTH);
        let cycle = lcm(health, damage);
        let a = gen_killed(cnt1, damage, health);
        let b = gen_killed(cnt2, damage, health);
        if cnt1 * health >= cycle || cnt2 * health >= cycle {
            continue;
        }
        dbg!(a.len(), b.len());
        if a.len() > 25 || b.len() > 25 {
            continue;
        }
        // let a_splits = split(&a);
        // let b_splits = split(&b);
        // let mut first_parts = vec![];
        // let mut second_parts = vec![];
        // for zz in [a_splits, b_splits].iter() {
        //     first_parts.push(zz[0].to_vec());
        //     if zz.len() == 1 {
        //     } else {
        //         assert_eq!(zz.len(), 2);
        //         second_parts.push(zz[1].to_vec());
        //     }
        // // }
        // first_parts.push(a.clone());
        // first_parts.push(b.clone());
        // let cmp = |a: &Vec<i64>, b: &Vec<i64>| -> Ordering {
        //     let c1 = calc_kills(&[a, b]);
        //     let c2 = calc_kills(&[b, a]);
        //     c1.cmp(&c2)
        // };
        // first_parts.sort_by(cmp);
        // second_parts.sort_by(cmp);
        // let mut all = vec![];
        // for f in [&first_parts, &second_parts].iter() {
        //     for x in f.iter() {
        //         all.push(&x[..]);
        //     }
        // }
        // let my = calc_kills(&all);
        let my = combine_kills3_slow(&a, &b);
        let my_ans = calc_kills(&[&my]);
        let optimal = combine_kills(&a, &b);
        let optimal_ans = calc_kills(&[&optimal]);
        if my_ans != optimal_ans {
            dbg!(cnt1, cnt2, health, damage);
            dbg!(a);
            dbg!(b);
            dbg!(optimal);
            dbg!(my);
            dbg!(optimal_ans);
            assert_eq!(my_ans, optimal_ans);
        }
    }
}

}
pub mod algo_lib {
pub mod collections {
pub mod array_2d {
use crate::algo_lib::io::output::Output;
use crate::algo_lib::io::output::Writable;
use crate::algo_lib::misc::num_traits::Number;
use std::io::Write;
use std::ops::Index;
use std::ops::IndexMut;
use std::ops::Mul;

// TODO: implement good Debug
#[derive(Clone, Debug)]
pub struct Array2D<T> {
    rows: usize,
    cols: usize,
    v: Vec<T>,
}

pub struct Iter<'a, T> {
    array: &'a Array2D<T>,
    row: usize,
    col: usize,
}

impl<T> Array2D<T>
where
    T: Clone,
{
    #[allow(unused)]
    pub fn new(empty: T, rows: usize, cols: usize) -> Self {
        Self {
            rows,
            cols,
            v: vec![empty; rows * cols],
        }
    }

    pub fn gen(rows: usize, cols: usize, mut f: impl FnMut(usize, usize) -> T) -> Self {
        let mut v = Vec::with_capacity(rows * cols);
        for r in 0..rows {
            for c in 0..cols {
                v.push(f(r, c));
            }
        }
        Self { rows, cols, v }
    }

    pub fn rows(&self) -> usize {
        self.rows
    }

    pub fn len(&self) -> usize {
        self.rows()
    }

    pub fn cols(&self) -> usize {
        self.cols
    }

    pub fn swap(&mut self, row1: usize, row2: usize) {
        assert!(row1 < self.rows);
        assert!(row2 < self.rows);
        if row1 != row2 {
            for col in 0..self.cols {
                self.v.swap(row1 * self.cols + col, row2 * self.cols + col);
            }
        }
    }

    pub fn transpose(&self) -> Self {
        Self::gen(self.cols, self.rows, |r, c| self[c][r].clone())
    }

    pub fn iter(&self) -> Iter<T> {
        Iter {
            array: self,
            row: 0,
            col: 0,
        }
    }
}

impl<T> Writable for Array2D<T>
where
    T: Writable,
{
    fn write(&self, output: &mut Output) {
        for r in 0..self.rows {
            self[r].write(output);
            output.write(&[b'\n']).unwrap();
        }
    }
}

impl<T> Index<usize> for Array2D<T> {
    type Output = [T];

    fn index(&self, index: usize) -> &Self::Output {
        &self.v[(index) * self.cols..(index + 1) * self.cols]
    }
}

impl<T> IndexMut<usize> for Array2D<T> {
    fn index_mut(&mut self, index: usize) -> &mut Self::Output {
        &mut self.v[(index) * self.cols..(index + 1) * self.cols]
    }
}

impl<T> Mul for &Array2D<T>
where
    T: Number,
{
    type Output = Array2D<T>;

    fn mul(self, rhs: Self) -> Self::Output {
        let n = self.rows;
        let m = self.cols;
        assert_eq!(m, rhs.rows);
        let k2 = rhs.cols;
        let mut res = Array2D::new(T::ZERO, n, k2);
        for i in 0..n {
            for j in 0..m {
                for k in 0..k2 {
                    res[i][k] += self[i][j] * rhs[j][k];
                }
            }
        }
        res
    }
}

impl<T> Array2D<T>
where
    T: Number,
{
    pub fn pown(&self, pw: usize) -> Self {
        assert_eq!(self.rows, self.cols);
        let n = self.rows;
        if pw == 0 {
            Self::gen(n, n, |r, c| if r == c { T::ONE } else { T::ZERO })
        } else if pw == 1 {
            self.clone()
        } else {
            let half = self.pown(pw / 2);
            let half2 = &half * &half;
            if pw & 1 == 0 {
                half2
            } else {
                &half2 * &self
            }
        }
    }
}

impl<'a, T> Iterator for Iter<'a, T> {
    type Item = &'a T;

    fn next(&mut self) -> Option<Self::Item> {
        if self.col == self.array.cols {
            self.col = 0;
            self.row += 1;
        }
        if self.row >= self.array.rows {
            return None;
        }
        let elem = &self.array[self.row][self.col];
        self.col += 1;
        Some(elem)
    }
}
}
pub mod last_exn {
use std::collections::BTreeSet;

pub trait LastExn<T> {
    fn last_exn(&self) -> &T;
}

impl<T> LastExn<T> for &[T] {
    fn last_exn(&self) -> &T {
        self.last().unwrap()
    }
}

impl<T> LastExn<T> for Vec<T> {
    fn last_exn(&self) -> &T {
        self.last().unwrap()
    }
}

impl<T> LastExn<T> for BTreeSet<T> {
    fn last_exn(&self) -> &T {
        self.iter().next_back().unwrap()
    }
}
}
}
pub mod geometry {
pub mod point {
use crate::algo_lib::collections::array_2d::Array2D;
use crate::f;
use crate::algo_lib::io::input::Input;
use crate::algo_lib::io::input::Readable;
use crate::algo_lib::iters::shifts::Shift;
use crate::algo_lib::misc::num_traits::Number;
use crate::algo_lib::misc::ord_f64::OrdF64;
use std::ops::Add;
use std::ops::AddAssign;
use std::ops::Sub;
use std::ops::SubAssign;

#[derive(Copy, Clone, Ord, PartialOrd, Eq, PartialEq, Hash, Debug)]
pub struct PointT<T: Number> {
    pub x: T,
    pub y: T,
}

impl<T: Number> PointT<T> {
    pub fn new(x: T, y: T) -> Self {
        Self { x, y }
    }

    pub fn dist2(&self, p2: &PointT<T>) -> T {
        let dx = self.x - p2.x;
        let dy = self.y - p2.y;
        dx * dx + dy * dy
    }

    pub fn dist_manh(&self, p2: &PointT<T>) -> T {
        let dx = self.x - p2.x;
        let dy = self.y - p2.y;
        let dx_abs = if dx < T::ZERO { T::ZERO - dx } else { dx };
        let dy_abs = if dy < T::ZERO { T::ZERO - dy } else { dy };
        dx_abs + dy_abs
    }

    pub fn angle_to(&self, other: &PointT<T>) -> OrdF64
    where
        f64: From<T>,
    {
        let dy = other.y - self.y;
        let dx = other.x - self.x;
        OrdF64(f64::atan2(dy.into(), dx.into()))
    }

    pub fn swap_x_y(&self) -> Self {
        Self::new(self.y, self.x)
    }

    pub fn vect_mul(p1: &PointT<T>, p2: &PointT<T>, p3: &PointT<T>) -> T {
        (p2.x - p1.x) * (p3.y - p1.y) - (p2.y - p1.y) * (p3.x - p1.x)
    }

    pub fn scal_mul(p1: &PointT<T>, p2: &PointT<T>, p3: &PointT<T>) -> T {
        Self::scal_mul2(&(*p2 - *p1), &(*p3 - *p1))
    }

    pub fn scal_mul2(p1: &PointT<T>, p2: &PointT<T>) -> T {
        p1.x * p2.x + p1.y * p2.y
    }

    pub fn vect_mul2(p1: &PointT<T>, p2: &PointT<T>) -> T {
        p1.x * p2.y - p1.y * p2.x
    }

    pub fn apply_shift(&self, shift: &Shift) -> Self {
        Self {
            x: self.x + T::from_i32(shift.dx),
            y: self.y + T::from_i32(shift.dy),
        }
    }

    pub fn shift(&self, dx: T, dy: T) -> Self {
        Self {
            x: self.x + dx,
            y: self.y + dy,
        }
    }

    pub fn scale(&self, coef: T) -> Self {
        Self {
            x: self.x * coef,
            y: self.y * coef,
        }
    }

    pub fn index_vec2d<'a, Elem>(&self, arr: &'a [Vec<Elem>]) -> Option<&'a Elem> {
        if self.x >= T::ZERO
            && self.x < T::from_i32(arr.len() as i32)
            && self.y >= T::ZERO
            && self.y < T::from_i32(arr[T::to_i32(self.x) as usize].len() as i32)
        {
            let x = T::to_i32(self.x) as usize;
            let y = T::to_i32(self.y) as usize;
            Some(&arr[x][y])
        } else {
            None
        }
    }

    pub fn index_arr2d<'a, Elem>(&self, arr: &'a Array2D<Elem>) -> Option<&'a Elem>
    where
        Elem: Clone,
    {
        if self.x >= T::ZERO
            && self.x < T::from_i32(arr.len() as i32)
            && self.y >= T::ZERO
            && self.y < T::from_i32(arr[T::to_i32(self.x) as usize].len() as i32)
        {
            let x = T::to_i32(self.x) as usize;
            let y = T::to_i32(self.y) as usize;
            Some(&arr[x][y])
        } else {
            None
        }
    }

    pub fn rotate_ccw(&self) -> Self {
        Self::new(T::ZERO - self.y, self.x)
    }

    pub const ZERO: PointT<T> = PointT {
        x: T::ZERO,
        y: T::ZERO,
    };
}

impl<T> Add for PointT<T>
where
    T: Number,
{
    type Output = Self;

    fn add(self, rhs: Self) -> Self::Output {
        Self::new(self.x + rhs.x, self.y + rhs.y)
    }
}

impl<T> AddAssign for PointT<T>
where
    T: Number,
{
    fn add_assign(&mut self, rhs: Self) {
        self.x += rhs.x;
        self.y += rhs.y;
    }
}

impl<T> Sub for PointT<T>
where
    T: Number,
{
    type Output = Self;

    fn sub(self, rhs: Self) -> Self::Output {
        Self::new(self.x - rhs.x, self.y - rhs.y)
    }
}

impl<T> SubAssign for PointT<T>
where
    T: Number,
{
    fn sub_assign(&mut self, rhs: Self) {
        self.x -= rhs.x;
        self.y -= rhs.y;
    }
}

impl<T> Readable for PointT<T>
where
    T: Number + Readable,
{
    fn read(input: &mut Input) -> Self {
        let x = input.read();
        let y = input.read();
        Self { x, y }
    }
}

#[derive(Copy, Clone, Ord, PartialOrd, Eq, PartialEq, Hash)]
pub struct PointWithIdT<T: Number> {
    pub p: PointT<T>,
    id: u32,
}

impl<T> PointWithIdT<T>
where
    T: Number,
{
    pub fn new(p: PointT<T>, id: usize) -> Self {
        Self { p, id: id as u32 }
    }

    pub fn id(&self) -> usize {
        self.id as usize
    }
}

impl PointT<OrdF64> {
    pub fn rotate_ccw_angle(&self, angle: OrdF64) -> Self {
        let cos = f!(angle.0.cos());
        let sin = f!(angle.0.sin());
        let x = self.x * cos - self.y * sin;
        let y = self.y * cos + self.x * sin;
        Self { x, y }
    }
}
}
}
pub mod io {
pub mod input {
use crate::algo_lib::collections::array_2d::Array2D;
use crate::algo_lib::misc::ord_f64::OrdF64;
use std::fmt::Debug;
use std::io::Read;
use std::marker::PhantomData;
use std::path::Path;
use std::str::FromStr;

pub struct Input {
    input: Box<dyn Read>,
    buf: Vec<u8>,
    at: usize,
    buf_read: usize,
}

macro_rules! read_integer_fun {
    ($t:ident) => {
        #[allow(unused)]
        pub fn $t(&mut self) -> $t {
            self.read_integer()
        }
    };
}

impl Input {
    const DEFAULT_BUF_SIZE: usize = 4096;

    ///
    /// Using with stdin:
    /// ```no_run
    /// use algo_lib::io::input::Input;
    /// let stdin = std::io::stdin();
    /// let input = Input::new(Box::new(stdin));
    /// ```
    ///
    /// For read files use ``new_file`` instead.
    ///
    ///
    pub fn new(input: Box<dyn Read>) -> Self {
        Self {
            input,
            buf: vec![0; Self::DEFAULT_BUF_SIZE],
            at: 0,
            buf_read: 0,
        }
    }

    pub fn new_file<P: AsRef<Path>>(path: P) -> Self {
        let file = std::fs::File::open(&path)
            .unwrap_or_else(|_| panic!("Can't open file: {:?}", path.as_ref().as_os_str()));
        Self::new(Box::new(file))
    }

    pub fn new_with_size(input: Box<dyn Read>, buf_size: usize) -> Self {
        Self {
            input,
            buf: vec![0; buf_size],
            at: 0,
            buf_read: 0,
        }
    }

    pub fn new_file_with_size<P: AsRef<Path>>(path: P, buf_size: usize) -> Self {
        let file = std::fs::File::open(&path)
            .unwrap_or_else(|_| panic!("Can't open file: {:?}", path.as_ref().as_os_str()));
        Self::new_with_size(Box::new(file), buf_size)
    }

    pub fn get(&mut self) -> Option<u8> {
        if self.refill_buffer() {
            let res = self.buf[self.at];
            self.at += 1;
            Some(res)
        } else {
            None
        }
    }

    pub fn peek(&mut self) -> Option<u8> {
        if self.refill_buffer() {
            Some(self.buf[self.at])
        } else {
            None
        }
    }

    pub fn skip_whitespace(&mut self) {
        while let Some(b) = self.peek() {
            if !char::from(b).is_whitespace() {
                return;
            }
            self.get();
        }
    }

    pub fn next_token(&mut self) -> Option<Vec<u8>> {
        self.skip_whitespace();
        let mut res = Vec::new();
        while let Some(c) = self.get() {
            if char::from(c).is_whitespace() {
                break;
            }
            res.push(c);
        }
        if res.is_empty() {
            None
        } else {
            Some(res)
        }
    }

    //noinspection RsSelfConvention
    pub fn is_exhausted(&mut self) -> bool {
        self.peek().is_none()
    }

    pub fn has_more_elements(&mut self) -> bool {
        !self.is_exhausted()
    }

    pub fn read<T: Readable>(&mut self) -> T {
        T::read(self)
    }

    pub fn vec<T: Readable>(&mut self, size: usize) -> Vec<T> {
        let mut res = Vec::with_capacity(size);
        for _ in 0usize..size {
            res.push(self.read());
        }
        res
    }

    pub fn string_vec(&mut self, size: usize) -> Vec<Vec<u8>> {
        let mut res = Vec::with_capacity(size);
        for _ in 0usize..size {
            res.push(self.string());
        }
        res
    }

    pub fn matrix<T: Readable>(&mut self, rows: usize, cols: usize) -> Array2D<T>
    where
        T: Clone,
    {
        Array2D::gen(rows, cols, |_, _| self.read())
    }

    pub fn read_line(&mut self) -> String {
        let mut res = String::new();
        while let Some(c) = self.get() {
            if c == b'\n' {
                break;
            }
            if c == b'\r' {
                if self.peek() == Some(b'\n') {
                    self.get();
                }
                break;
            }
            res.push(c.into());
        }
        res
    }

    #[allow(clippy::should_implement_trait)]
    pub fn into_iter<T: Readable>(self) -> InputIterator<T> {
        InputIterator {
            input: self,
            phantom: Default::default(),
        }
    }

    fn read_integer<T: FromStr>(&mut self) -> T
    where
        <T as FromStr>::Err: Debug,
    {
        let res = self.read_string();
        res.parse::<T>().unwrap()
    }

    fn read_string(&mut self) -> String {
        match self.next_token() {
            None => {
                panic!("Input exhausted");
            }
            Some(res) => unsafe { String::from_utf8_unchecked(res) },
        }
    }

    pub fn string_as_string(&mut self) -> String {
        self.read_string()
    }

    pub fn string(&mut self) -> Vec<u8> {
        self.read_string().into_bytes()
    }

    fn read_char(&mut self) -> char {
        self.skip_whitespace();
        self.get().unwrap().into()
    }

    fn read_float(&mut self) -> OrdF64 {
        self.read_string().parse().unwrap()
    }

    pub fn f64(&mut self) -> OrdF64 {
        self.read_float()
    }

    fn refill_buffer(&mut self) -> bool {
        if self.at == self.buf_read {
            self.at = 0;
            self.buf_read = self.input.read(&mut self.buf).unwrap();
            self.buf_read != 0
        } else {
            true
        }
    }

    read_integer_fun!(i32);
    read_integer_fun!(i64);
    read_integer_fun!(i128);
    read_integer_fun!(u32);
    read_integer_fun!(u64);
    read_integer_fun!(usize);
}

pub trait Readable {
    fn read(input: &mut Input) -> Self;
}

impl Readable for String {
    fn read(input: &mut Input) -> Self {
        input.read_string()
    }
}

impl Readable for char {
    fn read(input: &mut Input) -> Self {
        input.read_char()
    }
}

impl Readable for f64 {
    fn read(input: &mut Input) -> Self {
        input.read_string().parse().unwrap()
    }
}

impl<T: Readable> Readable for Vec<T> {
    fn read(input: &mut Input) -> Self {
        let size = input.read();
        input.vec(size)
    }
}

pub struct InputIterator<T: Readable> {
    input: Input,
    phantom: PhantomData<T>,
}

impl<T: Readable> Iterator for InputIterator<T> {
    type Item = T;

    fn next(&mut self) -> Option<Self::Item> {
        self.input.skip_whitespace();
        self.input.peek().map(|_| self.input.read())
    }
}

macro_rules! read_integer {
    ($t:ident) => {
        impl Readable for $t {
            fn read(input: &mut Input) -> Self {
                input.read_integer()
            }
        }
    };
}

read_integer!(i8);
read_integer!(i16);
read_integer!(i32);
read_integer!(i64);
read_integer!(i128);
read_integer!(isize);
read_integer!(u8);
read_integer!(u16);
read_integer!(u32);
read_integer!(u64);
read_integer!(u128);
read_integer!(usize);

macro_rules! tuple_readable {
    ( $( $name:ident )+ ) => {
        impl<$($name: Readable), +> Readable for ($($name,)+) {
            fn read(input: &mut Input) -> Self {
                ($($name::read(input),)+)
            }
        }
    }
}

tuple_readable! {T}
tuple_readable! {T U}
tuple_readable! {T U V}
tuple_readable! {T U V X}
tuple_readable! {T U V X Y}
tuple_readable! {T U V X Y Z}
tuple_readable! {T U V X Y Z A}
tuple_readable! {T U V X Y Z A B}
tuple_readable! {T U V X Y Z A B C}
tuple_readable! {T U V X Y Z A B C D}
tuple_readable! {T U V X Y Z A B C D E}
tuple_readable! {T U V X Y Z A B C D E F}
}
pub mod output {
use std::io::Write;

pub struct Output {
    output: Box<dyn Write>,
    buf: Vec<u8>,
    at: usize,
    auto_flush: bool,
}

impl Output {
    const DEFAULT_BUF_SIZE: usize = 4096;

    pub fn new(output: Box<dyn Write>) -> Self {
        Self {
            output,
            buf: vec![0; Self::DEFAULT_BUF_SIZE],
            at: 0,
            auto_flush: false,
        }
    }

    pub fn new_with_auto_flush(output: Box<dyn Write>) -> Self {
        Self {
            output,
            buf: vec![0; Self::DEFAULT_BUF_SIZE],
            at: 0,
            auto_flush: true,
        }
    }

    pub fn flush(&mut self) {
        if self.at != 0 {
            self.output.write_all(&self.buf[..self.at]).unwrap();
            self.at = 0;
            self.output.flush().expect("Couldn't flush output");
        }
    }

    pub fn print<T: Writable>(&mut self, s: &T) {
        s.write(self);
    }

    pub fn put(&mut self, b: u8) {
        self.buf[self.at] = b;
        self.at += 1;
        if self.at == self.buf.len() {
            self.flush();
        }
    }

    pub fn maybe_flush(&mut self) {
        if self.auto_flush {
            self.flush();
        }
    }

    pub fn print_per_line<T: Writable>(&mut self, arg: &[T]) {
        for i in arg {
            i.write(self);
            self.put(b'\n');
        }
    }

    pub fn print_iter<T: Writable, I: Iterator<Item = T>>(&mut self, iter: I) {
        let mut first = true;
        for e in iter {
            if first {
                first = false;
            } else {
                self.put(b' ');
            }
            e.write(self);
        }
    }

    pub fn print_iter_ref<'a, T: 'a + Writable, I: Iterator<Item = &'a T>>(&mut self, iter: I) {
        let mut first = true;
        for e in iter {
            if first {
                first = false;
            } else {
                self.put(b' ');
            }
            e.write(self);
        }
    }
}

impl Write for Output {
    fn write(&mut self, buf: &[u8]) -> std::io::Result<usize> {
        let mut start = 0usize;
        let mut rem = buf.len();
        while rem > 0 {
            let len = (self.buf.len() - self.at).min(rem);
            self.buf[self.at..self.at + len].copy_from_slice(&buf[start..start + len]);
            self.at += len;
            if self.at == self.buf.len() {
                self.flush();
            }
            start += len;
            rem -= len;
        }
        if self.auto_flush {
            self.flush();
        }
        Ok(buf.len())
    }

    fn flush(&mut self) -> std::io::Result<()> {
        self.flush();
        Ok(())
    }
}

pub trait Writable {
    fn write(&self, output: &mut Output);
}

impl Writable for &str {
    fn write(&self, output: &mut Output) {
        output.write_all(self.as_bytes()).unwrap();
    }
}

impl Writable for String {
    fn write(&self, output: &mut Output) {
        output.write_all(self.as_bytes()).unwrap();
    }
}

impl Writable for char {
    fn write(&self, output: &mut Output) {
        output.put(*self as u8);
    }
}

impl<T: Writable> Writable for [T] {
    fn write(&self, output: &mut Output) {
        output.print_iter_ref(self.iter());
    }
}

impl<T: Writable> Writable for Vec<T> {
    fn write(&self, output: &mut Output) {
        self[..].write(output);
    }
}

macro_rules! write_to_string {
    ($t:ident) => {
        impl Writable for $t {
            fn write(&self, output: &mut Output) {
                self.to_string().write(output);
            }
        }
    };
}

write_to_string!(u8);
write_to_string!(u16);
write_to_string!(u32);
write_to_string!(u64);
write_to_string!(u128);
write_to_string!(usize);
write_to_string!(i8);
write_to_string!(i16);
write_to_string!(i32);
write_to_string!(i64);
write_to_string!(i128);
write_to_string!(isize);
write_to_string!(f32);
write_to_string!(f64);

impl<T: Writable, U: Writable> Writable for (T, U) {
    fn write(&self, output: &mut Output) {
        self.0.write(output);
        output.put(b' ');
        self.1.write(output);
    }
}

impl<T: Writable, U: Writable, V: Writable> Writable for (T, U, V) {
    fn write(&self, output: &mut Output) {
        self.0.write(output);
        output.put(b' ');
        self.1.write(output);
        output.put(b' ');
        self.2.write(output);
    }
}

pub static mut OUTPUT: Option<Output> = None;

pub fn set_global_output_to_stdout() {
    unsafe {
        OUTPUT = Some(Output::new(Box::new(std::io::stdout())));
    }
}

pub fn set_global_output_to_file(path: &str) {
    unsafe {
        let out_file = std::fs::File::create(path).expect(&format!("Can't create file {}", path));
        OUTPUT = Some(Output::new(Box::new(out_file)));
    }
}

pub fn set_global_output_to_none() {
    unsafe {
        match &mut OUTPUT {
            None => {}
            Some(output) => output.flush(),
        }
        OUTPUT = None;
    }
}

pub fn output() -> &'static mut Output {
    unsafe {
        match &mut OUTPUT {
            None => {
                panic!("Global output wasn't initialized");
            }
            Some(output) => output,
        }
    }
}

#[macro_export]
macro_rules! out {
    ($first: expr $(,$args:expr )*) => {
        output().print(&$first);
        $(output().put(b' ');
        output().print(&$args);
        )*
        output().maybe_flush();
    }
}

#[macro_export]
macro_rules! out_line {
    ($first: expr $(, $args:expr )* ) => {
        {
            out!($first $(,$args)*);
            output().put(b'\n');
            output().maybe_flush();
        }
    };
    () => {
        {
            output().put(b'\n');
            output().maybe_flush();
        }
    };
}
}
pub mod task_io_settings {
pub enum TaskIoType {
    Std,
    File(String),
}

pub struct TaskIoSettings {
    pub is_interactive: bool,
    pub input: TaskIoType,
    pub output: TaskIoType,
}
}
pub mod task_runner {
use std::io::Write;

use super::input::Input;
use super::output::Output;
use super::output::OUTPUT;
use super::task_io_settings::TaskIoSettings;
use super::task_io_settings::TaskIoType;

pub fn run_task<Res>(io: TaskIoSettings, run: impl FnOnce(Input) -> Res) -> Res {
    let output: Box<dyn Write> = match io.output {
        TaskIoType::Std => Box::new(std::io::stdout()),
        TaskIoType::File(file) => {
            let out_file = std::fs::File::create(file).unwrap();
            Box::new(out_file)
        }
    };

    unsafe {
        if io.is_interactive {
            OUTPUT = Some(Output::new_with_auto_flush(output));
        } else {
            OUTPUT = Some(Output::new(output));
        }
    }

    let input = match io.input {
        TaskIoType::Std => {
            let sin = std::io::stdin();
            if io.is_interactive {
                Input::new_with_size(Box::new(sin), 1)
            } else {
                Input::new(Box::new(sin))
            }
        }
        TaskIoType::File(file) => {
            if io.is_interactive {
                Input::new_file_with_size(file, 1)
            } else {
                Input::new_file(file)
            }
        }
    };

    run(input)
}
}
}
pub mod iters {
pub mod shifts {
#[derive(Copy, Clone, Hash, Ord, PartialOrd, Eq, PartialEq)]
pub struct Shift {
    pub dx: i32,
    pub dy: i32,
}

// x goes down
// y goes right
pub const SHIFT_DOWN: Shift = Shift { dx: 1, dy: 0 };
pub const SHIFT_UP: Shift = Shift { dx: -1, dy: 0 };
pub const SHIFT_RIGHT: Shift = Shift { dx: 0, dy: 1 };
pub const SHIFT_LEFT: Shift = Shift { dx: 0, dy: -1 };

pub const SHIFTS_4: [Shift; 4] = [SHIFT_DOWN, SHIFT_LEFT, SHIFT_UP, SHIFT_RIGHT];
pub const SHIFTS_8: [Shift; 8] = [
    SHIFT_DOWN,
    SHIFT_LEFT,
    SHIFT_UP,
    SHIFT_RIGHT,
    Shift { dx: -1, dy: -1 },
    Shift { dx: -1, dy: 1 },
    Shift { dx: 1, dy: -1 },
    Shift { dx: 1, dy: 1 },
];

pub const SHIFTS_9: [Shift; 9] = [
    SHIFT_DOWN,
    SHIFT_LEFT,
    SHIFT_UP,
    SHIFT_RIGHT,
    Shift { dx: -1, dy: -1 },
    Shift { dx: -1, dy: 1 },
    Shift { dx: 1, dy: -1 },
    Shift { dx: 1, dy: 1 },
    Shift { dx: 0, dy: 0 },
];

pub fn shift_by_nswe(c: u8) -> Shift {
    match c {
        b'S' | b's' => SHIFT_DOWN,
        b'N' | b'n' => SHIFT_UP,
        b'E' | b'e' => SHIFT_RIGHT,
        b'W' | b'w' => SHIFT_LEFT,
        _ => panic!("Unexpected direction!"),
    }
}

pub fn shift_by_uldr(c: u8) -> Shift {
    match c {
        b'D' | b'd' => SHIFT_DOWN,
        b'U' | b'u' => SHIFT_UP,
        b'R' | b'r' => SHIFT_RIGHT,
        b'L' | b'l' => SHIFT_LEFT,
        _ => panic!("Unexpected direction!"),
    }
}
}
}
pub mod math {
pub mod gcd {
use crate::algo_lib::misc::num_traits::Number;

#[allow(dead_code)]
fn extended_gcd(a: i64, b: i64, x: &mut i64, y: &mut i64) -> i64 {
    if a == 0 {
        *x = 0;
        *y = 1;
        return b;
    }
    let mut x1 = 0;
    let mut y1 = 0;
    let d = extended_gcd(b % a, a, &mut x1, &mut y1);
    *x = y1 - (b / a) * x1;
    *y = x1;
    d
}

///
///
/// Find any solution to equation A*x + B*y = C
///
/// Returns [false] if [C] is not divisible by gcd(A, B)
///
#[allow(dead_code)]
pub fn diophantine(a: i64, b: i64, c: i64, x0: &mut i64, y0: &mut i64, g: &mut i64) -> bool {
    *g = extended_gcd(a.abs(), b.abs(), x0, y0);
    if c % *g != 0 {
        return false;
    }
    *x0 *= c / *g;
    *y0 *= c / *g;
    if a < 0 {
        *x0 *= -1;
    }
    if b < 0 {
        *y0 *= -1;
    }
    true
}

#[allow(dead_code)]
pub fn gcd<T>(x: T, y: T) -> T
where
    T: Number + std::ops::Rem<Output = T>,
{
    if x == T::ZERO {
        y
    } else {
        gcd(y % x, x)
    }
}

pub fn lcm<T>(x: T, y: T) -> T
where
    T: Number + std::ops::Rem<Output = T>,
{
    x / gcd(x, y) * y
}
}
}
pub mod misc {
pub mod binary_search {
use crate::algo_lib::misc::num_traits::Number;
use std::ops::Range;

pub fn binary_search_first_true<T>(range: Range<T>, mut f: impl FnMut(T) -> bool) -> T
where
    T: Number,
{
    // we can't store [range.start - 1] into [left], because it could overflow
    let mut left_plus_one = range.start;
    let mut right = range.end;
    while right > left_plus_one {
        let mid = left_plus_one + (right - left_plus_one) / T::TWO;
        if f(mid) {
            right = mid;
        } else {
            left_plus_one = mid + T::ONE;
        }
    }
    right
}

pub fn binary_search_last_true<T>(range: Range<T>, mut f: impl FnMut(T) -> bool) -> Option<T>
where
    T: Number,
{
    let first_false = binary_search_first_true(range.clone(), |x| !f(x));
    if first_false == range.start {
        None
    } else {
        Some(first_false - T::ONE)
    }
}

#[test]
fn simple_stress() {
    const N: usize = 50;
    for n in 1..N {
        for cnt_false in 0..=n {
            let mut a = vec![false; cnt_false];
            a.resize(n, true);
            let mut max_f_calls = ((n + 1) as f64).log2().ceil() as i32;
            let f_is_true = |id: usize| -> bool {
                max_f_calls -= 1;
                assert!(max_f_calls >= 0);
                a[id]
            };
            let result = binary_search_first_true(0..n, f_is_true);
            assert_eq!(result, cnt_false);
        }
    }
}
}
pub mod dbg_macro {
#[macro_export]
#[allow(unused_macros)]
macro_rules! dbg {
    ($first_val:expr, $($val:expr),+ $(,)?) => {
        eprint!("[{}:{}] {} = {:?}",
                    file!(), line!(), stringify!($first_val), &$first_val);
        ($(eprint!(", {} = {:?}", stringify!($val), &$val)),+,);
        eprintln!();
    };
    ($first_val:expr) => {
        eprintln!("[{}:{}] {} = {:?}",
                    file!(), line!(), stringify!($first_val), &$first_val)
    };
}
}
pub mod gen_vector {
pub fn gen_vec<T>(n: usize, mut f: impl FnMut(usize) -> T) -> Vec<T> {
    (0..n).map(|id| f(id)).collect()
}
}
pub mod min_max {
pub trait UpdateMinMax: PartialOrd + Sized {
    fn update_min(&mut self, other: Self) -> bool {
        if other < *self {
            *self = other;
            true
        } else {
            false
        }
    }

    fn update_max(&mut self, other: Self) -> bool {
        if other > *self {
            *self = other;
            true
        } else {
            false
        }
    }
}

impl<T: PartialOrd + Sized> UpdateMinMax for T {}

pub trait FindMinMaxPos {
    fn index_of_min(&self) -> usize;
    fn index_of_max(&self) -> usize;
}

impl<T: PartialOrd> FindMinMaxPos for [T] {
    fn index_of_min(&self) -> usize {
        let mut pos_of_best = 0;
        for (idx, val) in self.iter().enumerate().skip(1) {
            if val < &self[pos_of_best] {
                pos_of_best = idx;
            }
        }
        pos_of_best
    }

    fn index_of_max(&self) -> usize {
        let mut pos_of_best = 0;
        for (idx, val) in self.iter().enumerate().skip(1) {
            if val > &self[pos_of_best] {
                pos_of_best = idx;
            }
        }
        pos_of_best
    }
}

pub fn index_of_min_by<T, F>(n: usize, f: F) -> usize
where
    T: PartialOrd,
    F: Fn(usize) -> T,
{
    assert!(n > 0);
    let mut best_idx = 0;
    let mut best_val = f(0);
    for idx in 1..n {
        let cur_val = f(idx);
        if cur_val < best_val {
            best_val = cur_val;
            best_idx = idx;
        }
    }
    best_idx
}

pub fn index_of_max_by<T, F>(n: usize, f: F) -> usize
where
    T: PartialOrd,
    F: Fn(usize) -> T,
{
    assert!(n > 0);
    let mut best_idx = 0;
    let mut best_val = f(0);
    for idx in 1..n {
        let cur_val = f(idx);
        if cur_val > best_val {
            best_val = cur_val;
            best_idx = idx;
        }
    }
    best_idx
}
}
pub mod num_traits {
use std::fmt::Debug;
use std::ops::Add;
use std::ops::AddAssign;
use std::ops::Div;
use std::ops::DivAssign;
use std::ops::Mul;
use std::ops::MulAssign;
use std::ops::Sub;
use std::ops::SubAssign;

pub trait HasConstants<T> {
    const MAX: T;
    const MIN: T;
    const ZERO: T;
    const ONE: T;
    const TWO: T;
}

pub trait ConvI32<T> {
    fn from_i32(val: i32) -> T;
    fn to_i32(self) -> i32;
}

pub trait Number:
    Copy
    + Add<Output = Self>
    + AddAssign
    + Sub<Output = Self>
    + SubAssign
    + Mul<Output = Self>
    + MulAssign
    + Div<Output = Self>
    + DivAssign
    + Ord
    + PartialOrd
    + Eq
    + PartialEq
    + HasConstants<Self>
    + Default
    + Debug
    + Sized
    + ConvI32<Self>
{
}

impl<
        T: Copy
            + Add<Output = Self>
            + AddAssign
            + Sub<Output = Self>
            + SubAssign
            + Mul<Output = Self>
            + MulAssign
            + Div<Output = Self>
            + DivAssign
            + Ord
            + PartialOrd
            + Eq
            + PartialEq
            + HasConstants<Self>
            + Default
            + Debug
            + Sized
            + ConvI32<Self>,
    > Number for T
{
}

macro_rules! has_constants_impl {
    ($t: ident) => {
        impl HasConstants<$t> for $t {
            // TODO: remove `std` for new rust version..
            const MAX: $t = std::$t::MAX;
            const MIN: $t = std::$t::MIN;
            const ZERO: $t = 0;
            const ONE: $t = 1;
            const TWO: $t = 2;
        }

        impl ConvI32<$t> for $t {
            fn from_i32(val: i32) -> $t {
                val as $t
            }

            fn to_i32(self) -> i32 {
                self as i32
            }
        }
    };
}

has_constants_impl!(i32);
has_constants_impl!(i64);
has_constants_impl!(i128);
has_constants_impl!(u32);
has_constants_impl!(u64);
has_constants_impl!(u128);
has_constants_impl!(usize);
has_constants_impl!(u8);

impl ConvI32<Self> for f64 {
    fn from_i32(val: i32) -> Self {
        val as f64
    }

    fn to_i32(self) -> i32 {
        self as i32
    }
}

impl HasConstants<Self> for f64 {
    const MAX: Self = Self::MAX;
    const MIN: Self = -Self::MAX;
    const ZERO: Self = 0.0;
    const ONE: Self = 1.0;
    const TWO: Self = 2.0;
}
}
pub mod ord_f64 {
use crate::algo_lib::io::input::Input;
use crate::algo_lib::io::input::Readable;
use crate::algo_lib::io::output::Output;
use crate::algo_lib::io::output::Writable;
use crate::algo_lib::misc::num_traits::ConvI32;
use crate::algo_lib::misc::num_traits::HasConstants;
use std::cmp::min;
use std::cmp::Ordering;
use std::f64::consts::PI;
use std::fmt::Debug;
use std::fmt::Display;
use std::fmt::Formatter;
use std::io::Write;
use std::num::ParseFloatError;
use std::ops::Neg;
use std::ops::Rem;
use std::str::FromStr;

#[derive(PartialOrd, PartialEq, Copy, Clone, Default)]
pub struct OrdF64(pub f64);

impl OrdF64 {
    pub const EPS: Self = Self(1e-9);
    pub const SMALL_EPS: Self = Self(1e-4);
    pub const PI: Self = Self(PI);

    pub fn abs(&self) -> Self {
        Self(self.0.abs())
    }

    pub fn eq_with_eps(&self, other: &Self, eps: Self) -> bool {
        let abs_diff = (*self - *other).abs();
        abs_diff <= eps || abs_diff <= min(self.abs(), other.abs()) * eps
    }

    pub fn eq_with_default_eps(&self, other: &Self) -> bool {
        self.eq_with_eps(other, Self::EPS)
    }

    pub fn sqrt(&self) -> Self {
        Self(self.0.sqrt())
    }

    pub fn powf(&self, n: f64) -> Self {
        Self(self.0.powf(n))
    }
}

impl Eq for OrdF64 {}

impl Ord for OrdF64 {
    fn cmp(&self, other: &Self) -> Ordering {
        self.partial_cmp(other).unwrap()
    }
}

impl std::ops::Add for OrdF64 {
    type Output = Self;

    fn add(self, rhs: Self) -> Self::Output {
        Self(self.0 + rhs.0)
    }
}

impl std::ops::AddAssign for OrdF64 {
    fn add_assign(&mut self, rhs: Self) {
        self.0 += rhs.0;
    }
}

impl std::ops::Sub for OrdF64 {
    type Output = Self;

    fn sub(self, rhs: Self) -> Self::Output {
        Self(self.0 - rhs.0)
    }
}

impl std::ops::SubAssign for OrdF64 {
    fn sub_assign(&mut self, rhs: Self) {
        self.0 -= rhs.0;
    }
}

impl std::ops::Mul for OrdF64 {
    type Output = Self;

    fn mul(self, rhs: Self) -> Self::Output {
        Self(self.0 * rhs.0)
    }
}

impl std::ops::MulAssign for OrdF64 {
    fn mul_assign(&mut self, rhs: Self) {
        self.0 *= rhs.0;
    }
}

impl std::ops::Div for OrdF64 {
    type Output = Self;

    fn div(self, rhs: Self) -> Self::Output {
        Self(self.0 / rhs.0)
    }
}

impl std::ops::DivAssign for OrdF64 {
    fn div_assign(&mut self, rhs: Self) {
        self.0 /= rhs.0;
    }
}

impl Neg for OrdF64 {
    type Output = Self;

    fn neg(self) -> Self::Output {
        Self(-self.0)
    }
}

impl Display for OrdF64 {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        Display::fmt(&self.0, f)
    }
}

impl Debug for OrdF64 {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        Debug::fmt(&self.0, f)
    }
}

impl Writable for OrdF64 {
    fn write(&self, output: &mut Output) {
        output.write_fmt(format_args!("{}", self.0)).unwrap();
    }
}

impl Readable for OrdF64 {
    fn read(input: &mut Input) -> Self {
        Self(input.read::<f64>())
    }
}

impl HasConstants<Self> for OrdF64 {
    const MAX: Self = Self(f64::MAX);
    const MIN: Self = Self(-f64::MAX);
    const ZERO: Self = Self(0.0);
    const ONE: Self = Self(1.0);
    const TWO: Self = Self(2.0);
}

impl ConvI32<Self> for OrdF64 {
    fn from_i32(val: i32) -> Self {
        Self(val as f64)
    }

    fn to_i32(self) -> i32 {
        self.0 as i32
    }
}

impl FromStr for OrdF64 {
    type Err = ParseFloatError;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        match s.parse::<f64>() {
            Ok(value) => Ok(Self(value)),
            Err(error) => Err(error),
        }
    }
}

impl From<OrdF64> for f64 {
    fn from(x: OrdF64) -> Self {
        x.0
    }
}

impl Rem for OrdF64 {
    type Output = Self;

    fn rem(self, rhs: Self) -> Self::Output {
        Self(self.0 % rhs.0)
    }
}

#[macro_export]
macro_rules! f {
    ($a:expr) => {
        OrdF64($a)
    };
}

impl From<usize> for OrdF64 {
    fn from(x: usize) -> Self {
        f!(x as f64)
    }
}

impl From<i32> for OrdF64 {
    fn from(x: i32) -> Self {
        f!(x as f64)
    }
}

impl From<i64> for OrdF64 {
    fn from(x: i64) -> Self {
        f!(x as f64)
    }
}

impl From<f64> for OrdF64 {
    fn from(x: f64) -> Self {
        f!(x)
    }
}
}
pub mod pref_sum {
use crate::algo_lib::misc::num_traits::Number;

pub trait PrefSum<T> {
    fn pref_sum(&self) -> Vec<T>;
}

impl<T> PrefSum<T> for Vec<T>
where
    T: Number,
{
    fn pref_sum(&self) -> Vec<T> {
        let mut res = Vec::with_capacity(self.len() + 1);
        res.push(T::ZERO);
        let mut cur_sum = T::ZERO;
        for &val in self.iter() {
            cur_sum += val;
            res.push(cur_sum);
        }
        res
    }
}

impl<T> PrefSum<T> for &[T]
where
    T: Number,
{
    fn pref_sum(&self) -> Vec<T> {
        let mut res = Vec::with_capacity(self.len() + 1);
        res.push(T::ZERO);
        let mut cur_sum = T::ZERO;
        for &val in self.iter() {
            cur_sum += val;
            res.push(cur_sum);
        }
        res
    }
}
}
pub mod rand {
use crate::algo_lib::misc::gen_vector::gen_vec;
use crate::algo_lib::misc::num_traits::Number;
use std::ops::Range;
use std::time::SystemTime;
use std::time::UNIX_EPOCH;

#[allow(dead_code)]
pub struct Random {
    state: u64,
}

impl Random {
    pub fn gen_u64(&mut self) -> u64 {
        let mut x = self.state;
        x ^= x << 13;
        x ^= x >> 7;
        x ^= x << 17;
        self.state = x;
        x
    }

    #[allow(dead_code)]
    pub fn next_in_range(&mut self, from: usize, to: usize) -> usize {
        assert!(from < to);
        (from as u64 + self.gen_u64() % ((to - from) as u64)) as usize
    }

    pub fn gen_index<T>(&mut self, a: &[T]) -> usize {
        self.gen_in_range(0..a.len())
    }

    #[allow(dead_code)]
    pub fn gen_double(&mut self) -> f64 {
        (self.gen_u64() as f64) / (usize::MAX as f64)
    }

    #[allow(dead_code)]
    pub fn new(seed: u64) -> Self {
        let state = if seed == 0 { 787788 } else { seed };
        Self { state }
    }

    pub fn new_time_seed() -> Self {
        let time = SystemTime::now();
        let seed = (time.duration_since(UNIX_EPOCH).unwrap().as_nanos() % 1_000_000_000) as u64;
        if seed == 0 {
            Self::new(787788)
        } else {
            Self::new(seed)
        }
    }

    #[allow(dead_code)]
    pub fn gen_permutation(&mut self, n: usize) -> Vec<usize> {
        let mut result: Vec<_> = (0..n).collect();
        for i in 0..n {
            let idx = self.next_in_range(0, i + 1);
            result.swap(i, idx);
        }
        result
    }

    pub fn gen_in_range<T>(&mut self, range: Range<T>) -> T
    where
        T: Number,
    {
        let from = T::to_i32(range.start);
        let to = T::to_i32(range.end);
        assert!(from < to);
        let len = (to - from) as usize;
        T::from_i32(self.next_in_range(0, len) as i32 + from)
    }

    pub fn gen_vec<T>(&mut self, n: usize, range: Range<T>) -> Vec<T>
    where
        T: Number,
    {
        gen_vec(n, |_| self.gen_in_range(range.clone()))
    }

    pub fn gen_nonempty_range(&mut self, n: usize) -> Range<usize> {
        let x = self.gen_in_range(0..n);
        let y = self.gen_in_range(0..n);
        if x <= y {
            x..y + 1
        } else {
            y..x + 1
        }
    }

    pub fn gen_bool(&mut self) -> bool {
        self.gen_in_range(0..2) == 0
    }
}
}
pub mod rec_function {
// Copied from https://github.com/EgorKulikov/rust_algo/blob/master/algo_lib/src/misc/recursive_function.rs

use std::marker::PhantomData;

macro_rules! recursive_function {
    ($name: ident, $trait: ident, ($($type: ident $arg: ident,)*)) => {
        pub trait $trait<$($type, )*Output> {
            fn call(&mut self, $($arg: $type,)*) -> Output;
        }

        pub struct $name<F, $($type, )*Output>
        where
            F: FnMut(&mut dyn $trait<$($type, )*Output>, $($type, )*) -> Output,
        {
            f: F,
            $($arg: PhantomData<$type>,
            )*
            phantom_output: PhantomData<Output>,
        }

        impl<F, $($type, )*Output> $name<F, $($type, )*Output>
        where
            F: FnMut(&mut dyn $trait<$($type, )*Output>, $($type, )*) -> Output,
        {
            pub fn new(f: F) -> Self {
                Self {
                    f,
                    $($arg: Default::default(),
                    )*
                    phantom_output: Default::default(),
                }
            }
        }

        impl<F, $($type, )*Output> $trait<$($type, )*Output> for $name<F, $($type, )*Output>
        where
            F: FnMut(&mut dyn $trait<$($type, )*Output>, $($type, )*) -> Output,
        {
            fn call(&mut self, $($arg: $type,)*) -> Output {
                let const_ptr = &self.f as *const F;
                let mut_ptr = const_ptr as *mut F;
                unsafe { (&mut *mut_ptr)(self, $($arg, )*) }
            }
        }
    }
}

recursive_function!(RecursiveFunction0, Callable0, ());
recursive_function!(RecursiveFunction, Callable, (Arg arg,));
recursive_function!(RecursiveFunction2, Callable2, (Arg1 arg1, Arg2 arg2,));
recursive_function!(RecursiveFunction3, Callable3, (Arg1 arg1, Arg2 arg2, Arg3 arg3,));
recursive_function!(RecursiveFunction4, Callable4, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4,));
recursive_function!(RecursiveFunction5, Callable5, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5,));
recursive_function!(RecursiveFunction6, Callable6, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5, Arg6 arg6,));
recursive_function!(RecursiveFunction7, Callable7, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5, Arg6 arg6, Arg7 arg7,));
recursive_function!(RecursiveFunction8, Callable8, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5, Arg6 arg6, Arg7 arg7, Arg8 arg8,));
recursive_function!(RecursiveFunction9, Callable9, (Arg1 arg1, Arg2 arg2, Arg3 arg3, Arg4 arg4, Arg5 arg5, Arg6 arg6, Arg7 arg7, Arg8 arg8, Arg9 arg9,));
}
}
}
fn main() {
    crate::solution::submit();
}
